"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.retryPolicy = exports.requestWireguardDemoConfig = exports.requestHiddenPage = exports.requestGoogle = exports.WireguardDemoSchema = void 0;
var NodeSocket = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("@effect/platform-node/NodeSocket"));
var HttpClient = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("@effect/platform/HttpClient"));
var Schema = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("@effect/schema/Schema"));
var Effect = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("effect/Effect"));
var Function = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("effect/Function"));
var Option = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("effect/Option"));
var Schedule = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("effect/Schedule"));
var Sink = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("effect/Sink"));
var Stream = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("effect/Stream"));
var InternetSchemas = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("./InternetSchemas.js"));
var WireguardConfig = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("./WireguardConfig.js"));
var WireguardKey = /*#__PURE__*/_interopRequireWildcard( /*#__PURE__*/require("./WireguardKey.js"));
function _getRequireWildcardCache(e) {
  if ("function" != typeof WeakMap) return null;
  var r = new WeakMap(),
    t = new WeakMap();
  return (_getRequireWildcardCache = function (e) {
    return e ? t : r;
  })(e);
}
function _interopRequireWildcard(e, r) {
  if (!r && e && e.__esModule) return e;
  if (null === e || "object" != typeof e && "function" != typeof e) return {
    default: e
  };
  var t = _getRequireWildcardCache(r);
  if (t && t.has(e)) return t.get(e);
  var n = {
      __proto__: null
    },
    a = Object.defineProperty && Object.getOwnPropertyDescriptor;
  for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) {
    var i = a ? Object.getOwnPropertyDescriptor(e, u) : null;
    i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u];
  }
  return n.default = e, t && t.set(e, n), n;
}
/**
 * Utilities for connecting to the Wireguard demo server at demo.wireguard.com
 *
 * @since 1.0.0
 * @see https://git.zx2c4.com/wireguard-tools/plain/contrib/ncat-client-server/client.sh
 */

/**
 * @since 1.0.0
 * @category Schema
 */
const WireguardDemoSchema = exports.WireguardDemoSchema = /*#__PURE__*/Schema.transform(Schema.templateLiteral(Schema.literal("OK"), Schema.literal(":"), Schema.string, Schema.literal(":"), Schema.number, Schema.literal(":"), Schema.string, Schema.literal("\n")), Schema.struct({
  serverPort: InternetSchemas.Port,
  serverPublicKey: WireguardKey.WireguardKey,
  internalAddress: InternetSchemas.AddressFromString
}), input => {
  const [_status, key, port, address] = InternetSchemas.splitLiteral(input, ":");
  return {
    serverPort: Number.parseInt(port),
    serverPublicKey: key,
    internalAddress: address.slice(0, -1)
  };
}, ({
  internalAddress,
  serverPort,
  serverPublicKey
}) => `OK:${serverPublicKey}:${serverPort}:${internalAddress}\n`).annotations({
  identifier: "WireguardDemoSchema",
  description: "Wireguard demo server response"
});
/**
 * Creates a Wireguard configuration to connect to demo.wireguard.com. When
 * connected, you should be able to see the hidden page at 192.168.4.1
 *
 * @since 1.0.0
 */
const requestWireguardDemoConfig = ({
  privateKey,
  publicKey
} = WireguardKey.generateKeyPair()) => Function.pipe(Stream.make(`${publicKey}\n`), Stream.concat(Stream.never), Stream.pipeThroughChannelOrFail(NodeSocket.makeNetChannel({
  port: 42912,
  host: "demo.wireguard.com"
})), Stream.decodeText(), Stream.run(Sink.head()), Effect.map(Option.getOrUndefined), Effect.flatMap(Schema.decodeUnknown(WireguardDemoSchema)), Effect.flatMap(serverResponse => Schema.decode(WireguardConfig.WireguardConfig)({
  Dns: "1.1.1.1",
  PrivateKey: privateKey,
  Address: `${serverResponse.internalAddress.ip}/24`,
  ListenPort: 0,
  Peers: [{
    PublicKey: serverResponse.serverPublicKey,
    Endpoint: `demo.wireguard.com:${serverResponse.serverPort}`,
    AllowedIPs: ["0.0.0.0/0"],
    PersistentKeepalive: 25
  }]
})));
/** @internal */
exports.requestWireguardDemoConfig = requestWireguardDemoConfig;
const retryPolicy = exports.retryPolicy = /*#__PURE__*/Schedule.recurs(4).pipe( /*#__PURE__*/Schedule.addDelay(() => "3 seconds"));
/**
 * Attempts to view the hidden page on the demo.wireguard.com server, you should
 * only be able to see it when connected as a peer.
 *
 * @since 1.0.0
 */
const requestHiddenPage = exports.requestHiddenPage = /*#__PURE__*/Effect.gen(function* (λ) {
  const defaultClient = yield* λ(HttpClient.client.Client);
  const client = defaultClient.pipe(HttpClient.client.filterStatusOk);
  const request = HttpClient.request.get("http://192.168.4.1");
  return yield* λ(client(request).pipe(HttpClient.response.text, Effect.timeout("3 seconds")));
}).pipe( /*#__PURE__*/Effect.retry(retryPolicy));
/**
 * Attempts to connect to https://www.google.com to ensure that dns is still
 * working and we can connect to the internet when the wireguard tunnel is up.
 *
 * @since 1.0.0
 */
const requestGoogle = exports.requestGoogle = /*#__PURE__*/Effect.gen(function* (λ) {
  const defaultClient = yield* λ(HttpClient.client.Client);
  const client = defaultClient.pipe(HttpClient.client.filterStatusOk);
  const request = HttpClient.request.get("https://www.google.com");
  return yield* λ(client(request).pipe(HttpClient.response.text, Effect.timeout("3 seconds")));
}).pipe( /*#__PURE__*/Effect.retry(retryPolicy));
//# sourceMappingURL=WireguardDemo.js.map