/**
 * Utilities for connecting to the Wireguard demo server at demo.wireguard.com
 *
 * @since 1.0.0
 * @see https://git.zx2c4.com/wireguard-tools/plain/contrib/ncat-client-server/client.sh
 */
import * as HttpClient from "@effect/platform/HttpClient";
import * as Socket from "@effect/platform/Socket";
import * as ParseResult from "@effect/schema/ParseResult";
import * as Schema from "@effect/schema/Schema";
import * as Cause from "effect/Cause";
import * as Effect from "effect/Effect";
import * as InternetSchemas from "./InternetSchemas.js";
import * as WireguardConfig from "./WireguardConfig.js";
import * as WireguardKey from "./WireguardKey.js";
/**
 * @since 1.0.0
 * @category Api interface
 */
export interface $WireguardDemoSchema extends Schema.Annotable<$WireguardDemoSchema, {
    readonly serverPort: InternetSchemas.PortBrand;
    readonly serverPublicKey: WireguardKey.WireguardKey;
    readonly internalAddress: InternetSchemas.Address;
}, `OK:${string}:${number}:${string}\n`, never> {
}
/**
 * @since 1.0.0
 * @category Schema
 */
export declare const WireguardDemoSchema: $WireguardDemoSchema;
/**
 * Creates a Wireguard configuration to connect to demo.wireguard.com. When
 * connected, you should be able to see the hidden page at 192.168.4.1
 *
 * @since 1.0.0
 */
export declare const requestWireguardDemoConfig: ({ privateKey, publicKey }?: {
    readonly privateKey: string & import("effect/Brand").Brand<"WireguardKey">;
    readonly publicKey: string & import("effect/Brand").Brand<"WireguardKey">;
}) => Effect.Effect<WireguardConfig.WireguardConfig, Socket.SocketError | ParseResult.ParseError, never>;
/**
 * Attempts to view the hidden page on the demo.wireguard.com server, you should
 * only be able to see it when connected as a peer.
 *
 * @since 1.0.0
 */
export declare const requestHiddenPage: Effect.Effect<string, HttpClient.error.HttpClientError | Cause.TimeoutException, HttpClient.client.Client.Default>;
/**
 * Attempts to connect to https://www.google.com to ensure that dns is still
 * working and we can connect to the internet when the wireguard tunnel is up.
 *
 * @since 1.0.0
 */
export declare const requestGoogle: Effect.Effect<void, HttpClient.error.HttpClientError | Cause.TimeoutException, HttpClient.client.Client.Default>;
//# sourceMappingURL=WireguardDemo.d.ts.map